@@ -1,16 +1,19 @@
 """
 GravMag: 3D imaging using the Generalized Inverse method on synthetic gravity
-data (simple model)
+data (more complex model + noisy data)
 """
-from fatiando import gridder, mesher
+from fatiando import gridder, mesher, utils
 from fatiando.gravmag import prism, imaging
 from fatiando.vis import mpl, myv
 
 # Make some synthetic gravity data from a simple prism model
-model = [mesher.Prism(-1000,1000,-3000,3000,0,5000,{'density':1000})]
+model = [
+    mesher.Prism(-4000, -1000, -4000, -2000, 2000, 5000, {'density': 800}),
+    mesher.Prism(-1000, 1000, -1000, 1000, 1000, 6000, {'density': -800}),
+    mesher.Prism(2000, 4000, 3000, 4000, 0, 4000, {'density': 600})]
 shape = (25, 25)
 xp, yp, zp = gridder.regular((-5000, 5000, -5000, 5000), shape, z=-10)
-gz = prism.gz(xp, yp, zp, model)
+gz = utils.contaminate(prism.gz(xp, yp, zp, model), 0.1)
 
 # Plot the data
 mpl.figure()
@@ -23,12 +26,13 @@ mpl.m2km()
 mpl.show()
 
 # Run the Generalized Inverse
-mesh = imaging.geninv(xp, yp, zp, gz, shape, 0, 10000, 25)
+mesh = imaging.geninv(xp, yp, zp, gz, shape,
+                      0, 10000, 25)
 
 # Plot the results
 myv.figure()
-myv.prisms(model, 'density', style='wireframe', linewidth=5)
-myv.prisms(mesh, 'density', edges=False)
+myv.prisms(model, 'density', style='wireframe')
+myv.prisms(mesh, 'density', edges=False, linewidth=5)
 axes = myv.axes(myv.outline())
 myv.wall_bottom(axes.axes.bounds)
 myv.wall_north(axes.axes.bounds)
